@@ -1,4 +1,4 @@
-providers_version_num <- "1.8.0"
+providers_version_num <- "1.9.0"
 providers_data <- list(OpenStreetMap = "OpenStreetMap", OpenStreetMap.Mapnik = "OpenStreetMap.Mapnik", 
     OpenStreetMap.DE = "OpenStreetMap.DE", OpenStreetMap.CH = "OpenStreetMap.CH", 
     OpenStreetMap.France = "OpenStreetMap.France", OpenStreetMap.HOT = "OpenStreetMap.HOT", 
@@ -21,15 +21,16 @@ providers_data <- list(OpenStreetMap = "OpenStreetMap", OpenStreetMap.Mapnik = "
     Stamen.TonerHybrid = "Stamen.TonerHybrid", Stamen.TonerLines = "Stamen.TonerLines", 
     Stamen.TonerLabels = "Stamen.TonerLabels", Stamen.TonerLite = "Stamen.TonerLite", 
     Stamen.Watercolor = "Stamen.Watercolor", Stamen.Terrain = "Stamen.Terrain", 
-    Stamen.TerrainBackground = "Stamen.TerrainBackground", Stamen.TopOSMRelief = "Stamen.TopOSMRelief", 
-    Stamen.TopOSMFeatures = "Stamen.TopOSMFeatures", Esri = "Esri", 
-    Esri.WorldStreetMap = "Esri.WorldStreetMap", Esri.DeLorme = "Esri.DeLorme", 
-    Esri.WorldTopoMap = "Esri.WorldTopoMap", Esri.WorldImagery = "Esri.WorldImagery", 
-    Esri.WorldTerrain = "Esri.WorldTerrain", Esri.WorldShadedRelief = "Esri.WorldShadedRelief", 
-    Esri.WorldPhysical = "Esri.WorldPhysical", Esri.OceanBasemap = "Esri.OceanBasemap", 
-    Esri.NatGeoWorldMap = "Esri.NatGeoWorldMap", Esri.WorldGrayCanvas = "Esri.WorldGrayCanvas", 
-    OpenWeatherMap = "OpenWeatherMap", OpenWeatherMap.Clouds = "OpenWeatherMap.Clouds", 
-    OpenWeatherMap.CloudsClassic = "OpenWeatherMap.CloudsClassic", 
+    Stamen.TerrainBackground = "Stamen.TerrainBackground", Stamen.TerrainLabels = "Stamen.TerrainLabels", 
+    Stamen.TopOSMRelief = "Stamen.TopOSMRelief", Stamen.TopOSMFeatures = "Stamen.TopOSMFeatures", 
+    TomTom = "TomTom", TomTom.Basic = "TomTom.Basic", TomTom.Hybrid = "TomTom.Hybrid", 
+    TomTom.Labels = "TomTom.Labels", Esri = "Esri", Esri.WorldStreetMap = "Esri.WorldStreetMap", 
+    Esri.DeLorme = "Esri.DeLorme", Esri.WorldTopoMap = "Esri.WorldTopoMap", 
+    Esri.WorldImagery = "Esri.WorldImagery", Esri.WorldTerrain = "Esri.WorldTerrain", 
+    Esri.WorldShadedRelief = "Esri.WorldShadedRelief", Esri.WorldPhysical = "Esri.WorldPhysical", 
+    Esri.OceanBasemap = "Esri.OceanBasemap", Esri.NatGeoWorldMap = "Esri.NatGeoWorldMap", 
+    Esri.WorldGrayCanvas = "Esri.WorldGrayCanvas", OpenWeatherMap = "OpenWeatherMap", 
+    OpenWeatherMap.Clouds = "OpenWeatherMap.Clouds", OpenWeatherMap.CloudsClassic = "OpenWeatherMap.CloudsClassic", 
     OpenWeatherMap.Precipitation = "OpenWeatherMap.Precipitation", 
     OpenWeatherMap.PrecipitationClassic = "OpenWeatherMap.PrecipitationClassic", 
     OpenWeatherMap.Rain = "OpenWeatherMap.Rain", OpenWeatherMap.RainClassic = "OpenWeatherMap.RainClassic", 
@@ -40,19 +41,21 @@ providers_data <- list(OpenStreetMap = "OpenStreetMap", OpenStreetMap.Mapnik = "
     HERE.normalDayGrey = "HERE.normalDayGrey", HERE.normalDayMobile = "HERE.normalDayMobile", 
     HERE.normalDayGreyMobile = "HERE.normalDayGreyMobile", HERE.normalDayTransit = "HERE.normalDayTransit", 
     HERE.normalDayTransitMobile = "HERE.normalDayTransitMobile", 
-    HERE.normalNight = "HERE.normalNight", HERE.normalNightMobile = "HERE.normalNightMobile", 
-    HERE.normalNightGrey = "HERE.normalNightGrey", HERE.normalNightGreyMobile = "HERE.normalNightGreyMobile", 
+    HERE.normalDayTraffic = "HERE.normalDayTraffic", HERE.normalNight = "HERE.normalNight", 
+    HERE.normalNightMobile = "HERE.normalNightMobile", HERE.normalNightGrey = "HERE.normalNightGrey", 
+    HERE.normalNightGreyMobile = "HERE.normalNightGreyMobile", 
     HERE.normalNightTransit = "HERE.normalNightTransit", HERE.normalNightTransitMobile = "HERE.normalNightTransitMobile", 
     HERE.reducedDay = "HERE.reducedDay", HERE.reducedNight = "HERE.reducedNight", 
     HERE.basicMap = "HERE.basicMap", HERE.mapLabels = "HERE.mapLabels", 
     HERE.trafficFlow = "HERE.trafficFlow", HERE.carnavDayGrey = "HERE.carnavDayGrey", 
     HERE.hybridDay = "HERE.hybridDay", HERE.hybridDayMobile = "HERE.hybridDayMobile", 
     HERE.hybridDayTransit = "HERE.hybridDayTransit", HERE.hybridDayGrey = "HERE.hybridDayGrey", 
-    HERE.pedestrianDay = "HERE.pedestrianDay", HERE.pedestrianNight = "HERE.pedestrianNight", 
-    HERE.satelliteDay = "HERE.satelliteDay", HERE.terrainDay = "HERE.terrainDay", 
-    HERE.terrainDayMobile = "HERE.terrainDayMobile", FreeMapSK = "FreeMapSK", 
-    MtbMap = "MtbMap", CartoDB = "CartoDB", CartoDB.Positron = "CartoDB.Positron", 
-    CartoDB.PositronNoLabels = "CartoDB.PositronNoLabels", CartoDB.PositronOnlyLabels = "CartoDB.PositronOnlyLabels", 
+    HERE.hybridDayTraffic = "HERE.hybridDayTraffic", HERE.pedestrianDay = "HERE.pedestrianDay", 
+    HERE.pedestrianNight = "HERE.pedestrianNight", HERE.satelliteDay = "HERE.satelliteDay", 
+    HERE.terrainDay = "HERE.terrainDay", HERE.terrainDayMobile = "HERE.terrainDayMobile", 
+    FreeMapSK = "FreeMapSK", MtbMap = "MtbMap", CartoDB = "CartoDB", 
+    CartoDB.Positron = "CartoDB.Positron", CartoDB.PositronNoLabels = "CartoDB.PositronNoLabels", 
+    CartoDB.PositronOnlyLabels = "CartoDB.PositronOnlyLabels", 
     CartoDB.DarkMatter = "CartoDB.DarkMatter", CartoDB.DarkMatterNoLabels = "CartoDB.DarkMatterNoLabels", 
     CartoDB.DarkMatterOnlyLabels = "CartoDB.DarkMatterOnlyLabels", 
     CartoDB.Voyager = "CartoDB.Voyager", CartoDB.VoyagerNoLabels = "CartoDB.VoyagerNoLabels", 
@@ -152,12 +155,19 @@ providers_details_data <- list(OpenStreetMap = list(url = "//{s}.tile.openstreet
                 options = list(variant = "terrain", minZoom = 0L, 
                   maxZoom = 18L)), TerrainBackground = list(options = list(
                 variant = "terrain-background", minZoom = 0L, 
-                maxZoom = 18L)), TopOSMRelief = list(url = "//stamen-tiles-{s}.a.ssl.fastly.net/{variant}/{z}/{x}/{y}.{ext}", 
+                maxZoom = 18L)), TerrainLabels = list(options = list(
+                variant = "terrain-labels", minZoom = 0L, maxZoom = 18L)), 
+            TopOSMRelief = list(url = "//stamen-tiles-{s}.a.ssl.fastly.net/{variant}/{z}/{x}/{y}.{ext}", 
                 options = list(variant = "toposm-color-relief", 
                   ext = "jpg", bounds = structure(c(22L, 51L, 
                   -132L, -56L), .Dim = c(2L, 2L)))), TopOSMFeatures = list(
                 options = list(variant = "toposm-features", bounds = structure(c(22L, 
                 51L, -132L, -56L), .Dim = c(2L, 2L)), opacity = 0.9)))), 
+    TomTom = list(url = "https://{s}.api.tomtom.com/map/1/tile/{variant}/{style}/{z}/{x}/{y}.{ext}?key={apikey}", 
+        options = list(variant = "basic", maxZoom = 22L, attribution = "<a href=\"https://tomtom.com\" target=\"_blank\">&copy;  1992 - 2019 TomTom.</a> ", 
+            subdomains = "abcd", style = "main", ext = "png", 
+            apikey = "<insert your API key here>"), variants = list(
+            Basic = "basic", Hybrid = "hybrid", Labels = "labels")), 
     Esri = list(url = "//server.arcgisonline.com/ArcGIS/rest/services/{variant}/MapServer/tile/{z}/{y}/{x}", 
         options = list(variant = "World_Street_Map", attribution = "Tiles &copy; Esri"), 
         variants = list(WorldStreetMap = list(options = list(
@@ -198,8 +208,10 @@ providers_details_data <- list(OpenStreetMap = list(url = "//{s}.tile.openstreet
             normalDayGrey = "normal.day.grey", normalDayMobile = "normal.day.mobile", 
             normalDayGreyMobile = "normal.day.grey.mobile", normalDayTransit = "normal.day.transit", 
             normalDayTransitMobile = "normal.day.transit.mobile", 
-            normalNight = "normal.night", normalNightMobile = "normal.night.mobile", 
-            normalNightGrey = "normal.night.grey", normalNightGreyMobile = "normal.night.grey.mobile", 
+            normalDayTraffic = list(options = list(variant = "normal.traffic.day", 
+                base = "traffic", type = "traffictile")), normalNight = "normal.night", 
+            normalNightMobile = "normal.night.mobile", normalNightGrey = "normal.night.grey", 
+            normalNightGreyMobile = "normal.night.grey.mobile", 
             normalNightTransit = "normal.night.transit", normalNightTransitMobile = "normal.night.transit.mobile", 
             reducedDay = "reduced.day", reducedNight = "reduced.night", 
             basicMap = list(options = list(type = "basetile")), 
@@ -212,14 +224,15 @@ providers_details_data <- list(OpenStreetMap = list(url = "//{s}.tile.openstreet
             hybridDayTransit = list(options = list(base = "aerial", 
                 variant = "hybrid.day.transit")), hybridDayGrey = list(
                 options = list(base = "aerial", variant = "hybrid.grey.day")), 
-            pedestrianDay = "pedestrian.day", pedestrianNight = "pedestrian.night", 
-            satelliteDay = list(options = list(base = "aerial", 
-                variant = "satellite.day")), terrainDay = list(
-                options = list(base = "aerial", variant = "terrain.day")), 
-            terrainDayMobile = list(options = list(base = "aerial", 
-                variant = "terrain.day.mobile")))), FreeMapSK = list(
-        url = "http://t{s}.freemap.sk/T/{z}/{x}/{y}.jpeg", options = list(
-            minZoom = 8L, maxZoom = 16L, subdomains = "1234", 
+            hybridDayTraffic = list(options = list(variant = "hybrid.traffic.day", 
+                base = "traffic", type = "traffictile")), pedestrianDay = "pedestrian.day", 
+            pedestrianNight = "pedestrian.night", satelliteDay = list(
+                options = list(base = "aerial", variant = "satellite.day")), 
+            terrainDay = list(options = list(base = "aerial", 
+                variant = "terrain.day")), terrainDayMobile = list(
+                options = list(base = "aerial", variant = "terrain.day.mobile")))), 
+    FreeMapSK = list(url = "http://t{s}.freemap.sk/T/{z}/{x}/{y}.jpeg", 
+        options = list(minZoom = 8L, maxZoom = 16L, subdomains = "1234", 
             bounds = structure(c(47.204642, 49.830896, 15.996093, 
             22.576904), .Dim = c(2L, 2L)), attribution = "{attribution.OpenStreetMap}, vizualization CC-By-SA 2.0 <a href=\"http://freemap.sk\">Freemap.sk</a>")), 
     MtbMap = list(url = "http://tile.mtbmap.cz/mtbmap_tiles/{z}/{x}/{y}.png", 
